# Unbalanced Gromov-Wasserstein divergence
This repository contains an implementation on pytorch of the unbalaned Gromov-Wasserstein divergence presented in the paper [The Unbalanced Gromov Wasserstein Distance: Conic Formulation and Relaxation](https://arxiv.org/abs/2009.04266). It allows to compare weighted point clouds equipped with a cost matrix.

If you use this work for your research, please cite the paper:

```
@article{sejourne2020unbalanced,
  title={The Unbalanced Gromov Wasserstein Distance: Conic Formulation and Relaxation},
  author={S{\'e}journ{\'e}, Thibault and Vialard, Fran{\c{c}}ois-Xavier and Peyr{\'e}, Gabriel},
  journal={arXiv preprint arXiv:2009.04266},
  year={2020}
}
```
